<?php

/*
 * Boilerplate
 */

declare(strict_types=1);

namespace Univie\Basisklassifikation;

if (!defined('\\ABSPATH')) {
    exit();
}


/*
 * Base class for <input> fields.
 */

abstract class AbstractInput implements Interfaces\Input
{
    protected readonly string $id;

    protected string $type = 'text';

    protected function generate_id()
    {
        return sprintf(
            '%s-%s-%s',
            str_replace('\\', '-', strtolower(__NAMESPACE__)),
            $this->name,
            rand()
        );
    }

    protected function attrs(...$attrs): string
    {
        return implode(
            ' ',
            array_map(
                fn ($attr) => sprintf(
                    '%s="%s"',
                    $attr,
                    esc_attr($this->$attr)
                ),
                $attrs
            )
        );
    }

    public function __construct(
        public readonly string $name,
        public readonly string $label,
        public readonly ?string $desc = null,
        ?string $id = null
    ) {
        $this->id = $id ?? $this->generate_id();
    }

    public function render(): void
    {
        if ($this->label !== null) {
            ?>
                <label for='<?= esc_attr($this->id) ?>'>
                    <?= esc_html($this->label) ?>
                </label>
            <?php
        }

        ?>
            <input <?= $this->attrs('type', 'id', 'name') ?>>
        <?php

        if ($this->desc !== null) {
            ?>
                <p>
                    <?= esc_html($this->desc) ?>
                </p>
            <?php
        }
    }

    abstract public function process(): mixed;
}
