<?php

/*
 * Boilerplate
 */

declare(strict_types=1);

namespace Univie\Basisklassifikation;

if (!defined('\\ABSPATH')) {
    exit();
}


/*
 * Constants
 */

/* The name of the action used to create the nonce. */
const NONCE_ACTION = 'update-basisklassifikation';


/*
 * Process input
 */

$nonce = wp_create_nonce(NONCE_ACTION);

$fields = [
    new JSKOSSideloadInput(
        name: 'download',
        label: esc_html(
            'URL',
            'basisklassifikation'
        ),
        desc: esc_html__(
            'A URL to sideload a JSKOS ndJSON file from.',
            'basisklassifikation'
        )
    ),
    new JSKOSUploadInput(
        name: 'upload',
        label: esc_html__(
            'JSKOS ndJSON file',
            'basisklassifikation'
        ),
        desc: esc_html__(
            'Uploading may take a while; prefer side-loading.',
            'basisklassifikation'
        )
    ),
];

if (defined('\\WP_DEBUG') && \WP_DEBUG) {
    array_unshift(
        $fields,
        new DeleteTermsCheckbox(
            name: 'delete',
            label: esc_html__(
                'Delete existing terms?',
                'basisklassifikation'
            ),
            desc: esc_html__(
                'You neither need nor should do this to update classes.',
                'basisklassifikation'
            )
        )
    );
}

if (isset($_POST['submit'])) {
    if (
        current_user_can('manage_options') &&
        wp_verify_nonce($_POST['nonce'], NONCE_ACTION)
    ) {
        $count = 0;

        foreach ($fields as $field) {
            try {
                if ($field->process()) {
                    ++$count;
                }
            } catch (\JsonException|\RunTimeException|Errors\ABC $error) {
                admin_notify('error', $error->getMessage() . '.');
            }
        }

        if ($count == 0 && !isset($error)) {
            admin_notify('info', __(
                'No action ordered; no action performed.',
                'basisklassifikation'
            ));
        }
    } else {
        admin_notify('error', __(
            'Permission denied.',
            'basisklassifikation'
        ));
    }
}


/*
 * The form
 */

?>
<div class="wrap">
    <h1><?php _e('Basisklassifikation', 'basisklassifikation') ?></h1>
    <?php do_action('admin_notices'); ?>
    <div class='form-wrap'>
        <form method='post' name='basisklassifikation' enctype='multipart/form-data'>
            <?php foreach ($fields as $field): ?>
                <div class='form-field'>
                    <?php $field->render(); ?>
                </div>
            <?php endforeach; ?>
            <input type='hidden' name='nonce' value='<?= $nonce ?>'>
            <p class='submit'>
                <input type='submit' class='button button-primary' name='submit' value='<?= __('Submit', 'basisklassifikation')?>'>
            </p>
        </form>
    </div>
</div>
